local M = {}

local helper = require('scenariohelper')

local scenario = nil
local running = false

local maxScenarioDamage = 2500 --no unit
local maxWarningDamage = 1500 --no unit

local failureDelayTime = 2 --s
local failureMarkTime = 0 --s

local vehicleData

local function reset()
    running = false
	running = true
end

local function onRaceStart()
    reset()
	failureMarkTime = 0
    helper.trackVehicle('scenario_player0', 'playerCar')
end

local function fail(reason)
    scenarios.finish({failed = reason})
    reset()
end

local function success()     
    local finalTime = scenario.timer
    local minutes = math.floor(finalTime / 60);
    local seconds = finalTime - (minutes * 60);
    local timeStr = ''
    if minutes > 0 then
        timeStr = string.format("%02.0f:%05.2f", minutes, seconds)
    else
        timeStr = string.format("%0.2f", seconds) .. 's'
    end
    local result = {msg = 'Well done, you only did $'..math.floor(vehicleData.damage)..' worth of damage to the vehicle.  Your time: '..timeStr}
    scenarios.finish(result)
    reset()
end

local function onRaceWaypoint(data) 
    if data.waypointName == 'WP6' then
	success()
        -- guihooks.trigger('ScenarioFlashMessage', {{'test', 2}} )
    end
end


local function onRaceTick(raceTickTime)
  
    if not running then
        return
    end
	
    vehicleData = map.objects.playerCar

	--guihooks.trigger('ScenarioFlashMessage', {{vehicleData.damage, 1}} )
	
    if not vehicleData then
        return
    end

    if (vehicleData.damage > maxWarningDamage) and (vehicleData.damage <maxScenarioDamage) and (failureMarkTime == 0) then
		  guihooks.trigger('ScenarioFlashMessage', {{'This is not looking good!', 2}} )
    end

    if vehicleData.damage > maxScenarioDamage then
		if failureMarkTime == 0 then 
			failureMarkTime = scenario.timer
			--guihooks.trigger('ScenarioFlashMessage', {{'Time Marked: '..scenario.timer, 2}} )
		end
		if ((failureMarkTime + failureDelayTime) < scenario.timer) then
			fail("You've done too much damage to the vehicle.")
		end
	end
	
	
	
end

local function onScenarioChange(sc)
    scenario = sc
end

M.onRaceStart = onRaceStart
M.onRaceWaypoint = onRaceWaypoint
M.onRaceTick = onRaceTick
M.onScenarioChange = onScenarioChange

return M